<?php
/**
*
* search_ignore_words [Hungarian]
*
* @package language
* @version $Id: search_ignore_words.php 197 2009-10-18 20:12:18Z fberci $
* @copyright (c) 2007 „Magyar phpBB Közösség fordítók”
* @license http://opensource.org/licenses/gpl-license.php GNU Public License
* Original copyright: (c) 2005 phpBB Group
*
*/

$words = array(
	'a',
	'abba',
	'abban',
	'abból',
	'addig',
	'ahhoz',
	'ahogy',
	'ahol',
	'akár',
	'aki',
	'akik',
	'akkor',
	'alá',
	'alád',
	'alájuk',
	'alám',
	'alánk',
	'alapján',
	'alátok',
	'alatt',
	'alatta',
	'alattad',
	'alattam',
	'alattatok',
	'alattuk',
	'alattunk',
	'alól',
	'alóla',
	'alólad',
	'alólam',
	'alólatok',
	'alóluk',
	'alólunk',
	'által',
	'általában',
	'ám',
	'amely',
	'amelyből',
	'amelyek',
	'amelyekben',
	'amelyeket',
	'amelyet',
	'amelyik',
	'amelynek',
	'ami',
	'amíg',
	'amikor',
	'amit',
	'amolyan',
	'amott',
	'annak',
	'annál',
	'arra',
	'arról',
	'át',
	'attól',
	'az',
	'azért',
	'aznap',
	'azok',
	'azokat',
	'azokba',
	'azokban',
	'azokból',
	'azokért',
	'azokhoz',
	'azokig',
	'azokká',
	'azokkal',
	'azoknak',
	'azoknál',
	'azokon',
	'azokra',
	'azokról',
	'azoktól',
	'azon',
	'azonban',
	'azonnal',
	'azt',
	'aztán',
	'azután',
	'azzá',
	'azzal',
	'bal',
	'balra',
	'ban',
	'bár',
	'bárcsak',
	'bármilyen',
	'be',
	'belé',
	'beléd',
	'beléjük',
	'belém',
	'belénk',
	'belétek',
	'belőle',
	'belőled',
	'belőlem',
	'belőletek',
	'belőlük',
	'belőlünk',
	'belül',
	'ben',
	'benne',
	'benned',
	'bennem',
	'bennetek',
	'bennük',
	'bennünk',
	'búcsú',
	'cikk',
	'cikkek',
	'cikkeket',
	'csak',
	'csakhogy',
	'csupán',
	'de',
	'dehogy',
	'e',
	'ebbe',
	'ebben',
	'ebből',
	'eddig',
	'egész',
	'egészen',
	'egy',
	'egyéb',
	'egyebek',
	'egyebet',
	'egyébként',
	'egyedül',
	'egyelőre',
	'egyes',
	'egyet',
	'egyetlen',
	'egyik',
	'egymás',
	'egyre',
	'egyszerre',
	'együtt',
	'ehhez',
	'ekkor',
	'el',
	'elé',
	'eléd',
	'elég',
	'eleinte',
	'eléjük',
	'elém',
	'elénk',
	'elétek',
	'éljen',
	'ellen',
	'ellenére',
	'ellenes',
	'elleni',
	'elmondta',
	'elő',
	'előbb',
	'elől',
	'előle',
	'előled',
	'előlem',
	'előletek',
	'előlük',
	'előlünk',
	'először',
	'előtt',
	'előtte',
	'előtted',
	'előttem',
	'előttetek',
	'előttük',
	'előttünk',
	'előző',
	'első',
	'elsők',
	'elsősorban',
	'elsőt',
	'emilyen',
	'én',
	'engem',
	'ennek',
	'ennél',
	'ennyi',
	'enyém',
	'éppen',
	'erre',
	'erről',
	'érte',
	'érted',
	'értem',
	'értetek',
	'értük',
	'értünk',
	'és',
	'esetben',
	'esetleg',
	'ettől',
	'év',
	'évben',
	'éve',
	'évek',
	'éves',
	'évi',
	'évvel',
	'ez',
	'ezek',
	'ezekbe',
	'ezekben',
	'ezekből',
	'ezeken',
	'ezekért',
	'ezeket',
	'ezekhez',
	'ezekig',
	'ezekké',
	'ezekkel',
	'ezeknek',
	'ezeknél',
	'ezekre',
	'ezekről',
	'ezektől',
	'ezen',
	'ezentúl',
	'ezer',
	'ezért',
	'ezret',
	'ezt',
	'ezután',
	'ezzé',
	'ezzel',
	'fel',
	'felé',
	'felek',
	'felet',
	'felett',
	'fent',
	'fenti',
	'fölé',
	'gyakran',
	'ha',
	'halló',
	'hamar',
	'hanem',
	'hány',
	'hányszor',
	'harmadik',
	'harmadikat',
	'hármat',
	'harminc',
	'három',
	'hat',
	'hát',
	'hátha',
	'hatodik',
	'hatodikat',
	'hatot',
	'hátulsó',
	'hatvan',
	'hello',
	'helló',
	'helyett',
	'hét',
	'hetedik',
	'hetediket',
	'hetet',
	'hetven',
	'hiába',
	'hirtelen',
	'hiszen',
	'hogy',
	'hogyan',
	'hol',
	'holnap',
	'holnapot',
	'honnan',
	'hova',
	'hozzá',
	'hozzád',
	'hozzájuk',
	'hozzám',
	'hozzánk',
	'hozzátok',
	'hurrá',
	'húsz',
	'huszadik',
	'ide-оda',
	'idén',
	'igazán',
	'igen',
	'így',
	'ill',
	'ill.',
	'illetve',
	'ilyen',
	'ilyenkor',
	'immár',
	'inkább',
	'is',
	'ismét',
	'ison',
	'itt',
	'jelenleg',
	'jó',
	'jobban',
	'jobbra',
	'jól',
	'jólesik',
	'jóval',
	'jövőre',
	'kell',
	'kellene',
	'kellett',
	'kelljen',
	'kéne',
	'képest',
	'kérem',
	'keressünk',
	'keresztül',
	'kérlek',
	'késő',
	'később',
	'későn',
	'kész',
	'két',
	'kétszer',
	'ketten',
	'kettő',
	'kettőt',
	'kevés',
	'ki',
	'kiben',
	'kiből',
	'kicsit',
	'kicsoda',
	'kié',
	'kiért',
	'kihez',
	'kik',
	'kikbe',
	'kikben',
	'kikből',
	'kiken',
	'kikért',
	'kiket',
	'kikhez',
	'kikké',
	'kikkel',
	'kiknek',
	'kiknél',
	'kikre',
	'kikről',
	'kiktől',
	'kilenc',
	'kilencedik',
	'kilencediket',
	'kilencet',
	'kilencven',
	'kin',
	'kinek',
	'kinél',
	'kire',
	'kiről',
	'kit',
	'kitől',
	'kivé',
	'kivel',
	'kívül',
	'korábban',
	'körül',
	'köszi',
	'köszönhetően',
	'köszönöm',
	'közben',
	'közé',
	'közel',
	'közepén',
	'közepesen',
	'között',
	'közül',
	'külön',
	'különben',
	'különböző',
	'különbözőbb',
	'különbözőek',
	'lassan',
	'le',
	'legalább',
	'legyen',
	'lehet',
	'lehetetlen',
	'lehetett',
	'lehetőleg',
	'lehetőség',
	'lenne',
	'lennék',
	'lennének',
	'lenni',
	'lesz',
	'leszek',
	'lesznek',
	'leszünk',
	'lett',
	'lettek',
	'lettem',
	'lettünk',
	'lévő',
	'ma',
	'maga',
	'magad',
	'magam',
	'magát',
	'magatokat',
	'magukat',
	'magunkat',
	'mai',
	'majd',
	'majdnem',
	'manapság',
	'már',
	'más',
	'másik',
	'másikat',
	'másnap',
	'második',
	'másodszor',
	'mások',
	'másokat',
	'mást',
	'meg',
	'megcsinál',
	'megcsinálnak',
	'megint',
	'mégis',
	'megvan',
	'mellé',
	'melléd',
	'melléjük',
	'mellém',
	'mellénk',
	'mellétek',
	'mellett',
	'mellette',
	'melletted',
	'mellettem',
	'mellettetek',
	'mellettük',
	'mellettünk',
	'mellől',
	'mellőle',
	'mellőled',
	'mellőlem',
	'mellőletek',
	'mellőlük',
	'mellőlünk',
	'mely',
	'melyek',
	'melyik',
	'mennyi',
	'mert',
	'mi',
	'miatt',
	'miatta',
	'miattad',
	'miattam',
	'miattatok',
	'miattuk',
	'miattunk',
	'mibe',
	'miben',
	'miből',
	'miért',
	'míg',
	'mihez',
	'mik',
	'mikbe',
	'mikben',
	'mikből',
	'miken',
	'mikért',
	'miket',
	'mikhez',
	'mikké',
	'mikkel',
	'miknek',
	'miknél',
	'mikor',
	'mikre',
	'mikről',
	'miktől',
	'milyen',
	'min',
	'mind',
	'mindegyik',
	'mindegyiket',
	'minden',
	'mindenesetre',
	'mindenki',
	'mindent',
	'mindenütt',
	'mindig',
	'mindketten',
	'minek',
	'minél',
	'minket',
	'mint',
	'mintha',
	'mire',
	'miről',
	'mit',
	'mitől',
	'mivé',
	'mivel',
	'mondta',
	'most',
	'mostanáig',
	'mögé',
	'mögéd',
	'mögéjük',
	'mögém',
	'mögénk',
	'mögétek',
	'mögött',
	'mögötte',
	'mögötted',
	'mögöttem',
	'mögöttetek',
	'mögöttük',
	'mögöttünk',
	'mögül',
	'mögüle',
	'mögüled',
	'mögülem',
	'mögületek',
	'mögülük',
	'mögülünk',
	'múltkor',
	'múlva',
	'na',
	'nagy',
	'nagyobb',
	'nagyon',
	'nála',
	'nálad',
	'nálam',
	'nálatok',
	'náluk',
	'nálunk',
	'naponta',
	'napot',
	'ne',
	'négy',
	'negyedik',
	'negyediket',
	'négyet',
	'negyven',
	'néha',
	'néhány',
	'neked',
	'nekem',
	'neki',
	'nekik',
	'nektek',
	'nekünk',
	'nélkül',
	'nem',
	'nemcsak',
	'nemrég',
	'nincs',
	'nyolc',
	'nyolcadik',
	'nyolcadikat',
	'nyolcat',
	'nyolcvan',
	'olyan',
	'onnan',
	'óta',
	'ott',
	'ő',
	'ők',
	'őket',
	'ön',
	'önbe',
	'önben',
	'önből',
	'önért',
	'önhöz',
	'önnek',
	'önnel',
	'önök',
	'önökbe',
	'önökben',
	'önökből',
	'önökért',
	'önöket',
	'önökhöz',
	'önökkel',
	'önöknek',
	'önöknél',
	'önökön',
	'önökre',
	'önökről',
	'önöktől',
	'önön',
	'önre',
	'önről',
	'önt',
	'öntől',
	'össze',
	'öt',
	'ötödik',
	'ötödiket',
	'ötöt',
	'ötven',
	'pár',
	'pedig',
	'például',
	'persze',
	'rá',
	'rád',
	'rajta',
	'rajtad',
	'rajtam',
	'rajtatok',
	'rajtuk',
	'rajtunk',
	'rájuk',
	'rám',
	'ránk',
	'rátok',
	'régen',
	'régóta',
	'rendben',
	'részére',
	'róla',
	'rólad',
	'rólam',
	'rólatok',
	'róluk',
	'rólunk',
	'rosszul',
	'rögtön',
	's',
	'saját',
	'se',
	'sem',
	'semmi',
	'semmilyen',
	'semmiség',
	'senki',
	'soha',
	'sok',
	'sokáig',
	'sokan',
	'sokat',
	'sokkal',
	'sokszor',
	'során',
	'sőt',
	'stb',
	'számára',
	'száz',
	'századik',
	'százat',
	'szemben',
	'szépen',
	'szerbusz',
	'szerint',
	'szerinte',
	'szerinted',
	'szerintem',
	'szerintetek',
	'szerintük',
	'szerintünk',
	'szervusz',
	'szia',
	'sziasztok',
	'szíves',
	'szívesen',
	'szíveskedjék',
	'talán',
	'tavaly',
	'távol',
	'te',
	'téged',
	'tegnap',
	'tegnapelőtt',
	'tehát',
	'tele',
	'teljes',
	'tényleg',
	'tessék',
	'ti',
	'tied',
	'titeket',
	'tíz',
	'tizedik',
	'tizediket',
	'tizenegy',
	'tizenegyedik',
	'tizenhárom',
	'tizenhat',
	'tizenhét',
	'tizenkét',
	'tizenkettedik',
	'tizenkettő',
	'tizenkilenc',
	'tizennégy',
	'tizennyolc',
	'tizenöt',
	'tizet',
	'tovább',
	'továbbá',
	'további',
	'több',
	'többi',
	'többször',
	'tőle',
	'tőled',
	'tőlem',
	'tőletek',
	'tőlük',
	'tőlünk',
	'túl',
	'úgy',
	'ugyanakkor',
	'ugyanez',
	'ugyanis',
	'ugye',
	'úgyis',
	'úgynevezett',
	'új',
	'újabb',
	'újra',
	'úr',
	'urak',
	'uram',
	'urat',
	'után',
	'utána',
	'utoljára',
	'utolsó',
	'vagy',
	'vagyis',
	'vagyok',
	'vagytok',
	'vagyunk',
	'vajon',
	'valahol',
	'valaki',
	'valakit',
	'valamelyik',
	'valami',
	'valamint',
	'való',
	'van',
	'vannak',
	'végén',
	'végre',
	'végül',
	'vele',
	'veled',
	'velem',
	'veletek',
	'velük',
	'velünk',
	'vissza',
	'viszlát',
	'viszont',
	'viszontlátásra',
	'volna',
	'volnának',
	'volnék',
	'volt',
	'voltak',
	'voltam',
	'voltunk',
	'LOL',
	'SZVSZ',
);

?>
